@@ -138,6 +138,11 @@ def log(a: Numeric):
     return np.log(a)
 
 
+@dispatch
+def log1p(a: Numeric):
+    return np.log1p(a)
+
+
 @dispatch
 def sin(a: Numeric):
     return np.sin(a)
